.. _ng-based-component-updater:

NgBasedComponentUpdater
=======================

.. inheritance-diagram:: gmmvi.optimization.gmmvi_modules.ng_based_component_updater.NgBasedComponentUpdater gmmvi.optimization.gmmvi_modules.ng_based_component_updater.DirectNgBasedComponentUpdater gmmvi.optimization.gmmvi_modules.ng_based_component_updater.NgBasedComponentUpdaterIblr gmmvi.optimization.gmmvi_modules.ng_based_component_updater.KLConstrainedNgBasedComponentUpdater
    :parts: -4

.. autoclass:: gmmvi.optimization.gmmvi_modules.ng_based_component_updater.NgBasedComponentUpdater
   :members:
   :undoc-members:

.. _direct-comp:

DirectNgBasedComponentUpdater
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.ng_based_component_updater.DirectNgBasedComponentUpdater
   :members:
   :undoc-members:

.. _kl-comp:

KLConstrainedNgBasedComponentUpdater
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.ng_based_component_updater.KLConstrainedNgBasedComponentUpdater
   :members:
   :undoc-members:

.. _iblr:

NgBasedComponentUpdaterIblr
~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.ng_based_component_updater.NgBasedComponentUpdaterIblr
   :members:
   :undoc-members:

.. toctree::
   :maxdepth: 2
   :glob: